@@ -1,7 +1,7 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/display.c,v 1.60 2005/11/17 17:14:05 richb Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/display.c,v 1.62 2006/01/10 18:00:13 richb Exp $
  *
- *  Copyright (c) 1987-2005 Sun Microsystems, Inc. All Rights Reserved.
+ *  Copyright (c) 1987-2006 Sun Microsystems, Inc. All Rights Reserved.
  *           
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -28,7 +28,6 @@
 #include "mpmath.h"
 
 static char *make_eng_sci(int *, int);
-static char *make_fixed(int *, int, int);
 
 /* Add in the thousand separators characters if required and if we are
  * currently in the decimal numeric base, use the "right" radix character.
@@ -173,8 +172,8 @@ initialise()
  * maximum number of digits specified.
  */
 
-static char *
-make_fixed(int *MPnumber, int base, int cmax)
+char *
+make_fixed(int *MPnumber, char *str, int base, int cmax, int toclear)
 {
     char half[4], *optr;
     int MP1base[MP_SIZE], MP1[MP_SIZE], MP2[MP_SIZE], MPval[MP_SIZE];
@@ -182,7 +181,7 @@ make_fixed(int *MPnumber, int base, int cmax)
     int ddig;                   /* Number of digits to left of decimal sep. */
     int dval, n;
  
-    optr = v->fnum;
+    optr = str;
     mpabs(MPnumber, MPval);
     n = 0;
     mpcim(&n, MP1);
@@ -228,21 +227,23 @@ make_fixed(int *MPnumber, int base, int cmax)
         mpaddi(MPval, &dval, MPval);
     }    
     *optr++ = '\0';
-    v->toclear = 1;
+    if (toclear == TRUE) {
+        v->toclear = 1;
+    }
     v->pointed = 0;
 
     if (!v->show_zeroes && v->accuracy != 0) {
-        optr = v->fnum + strlen(v->fnum) - 1;
+        optr = str + strlen(str) - 1;
         while (*optr == '0') {
             optr--;
         }
-    if (optr < v->fnum || *optr != '.') {
+    if (optr < str || *optr != '.') {
         optr++;
     }
         *optr = '\0';
     }
 
-    return(v->fnum);
+    return(str);
 }
 
 
@@ -271,7 +272,7 @@ make_number(int *MPnumber, int base, BOOLEAN ignoreError)
         (v->dtype == FIX && val != 0.0 && (val > max_fix[base]))) {
         return(make_eng_sci(MPnumber, base));
     } else {
-        return(make_fixed(MPnumber, base, MAX_DIGITS));
+        return(make_fixed(MPnumber, v->fnum, base, MAX_DIGITS, TRUE));
     }
 }
 
@@ -340,7 +341,7 @@ make_eng_sci(int *MPnumber, int base)
         }
     }
  
-    STRCPY(fixed, make_fixed(MPmant, base, MAX_DIGITS-6));
+    STRCPY(fixed, make_fixed(MPmant, v->fnum, base, MAX_DIGITS-6, TRUE));
     len = strlen(fixed);
     for (i = 0; i < len; i++) {
         *optr++ = fixed[i];
@@ -394,6 +395,8 @@ MPstr_to_num(char *str, enum base_type base, int *MPval)
     int i, inum;
     int exp      = 0;
     int exp_sign = 1;
+    char *lnp = get_localized_numeric_point();
+    assert(lnp && strlen(lnp) == 1);
 
     i = 0;
     mpcim(&i, MPval);
@@ -406,7 +409,7 @@ MPstr_to_num(char *str, enum base_type base, int *MPval)
         optr++;
     }
 
-    if (*optr == '.') {
+    if (*optr == '.' || *optr == *lnp) {
         optr++;
         for (i = 1; (inum = char_val(*optr)) >= 0; i++) {
             mppwr(MPbase, &i, MP1);
